@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Author: Don Welch
+# Author: Don Welch, Naga Samrat Chowdary Narla,
 
 # Local
 from base.g import *
@@ -99,6 +99,8 @@ TECH_CLASSES = [
     "Python",
     "OJ7000",
     "Pyramid",
+    "Python10",
+    "Mimas",
 ]
 
 TECH_CLASSES.sort()
@@ -149,6 +151,8 @@ TECH_CLASS_PDLS = {
     "Corbett"       : 'pcl3',
     "Python"        : 'pcl3',
     "OJ7000"        : 'pcl3',
+    "Python10"      : 'pcl3',
+    "Mimas"      : 'pcl3',
 }
 
 PDL_TYPE_PCL = 0  # less preferred
@@ -200,6 +204,8 @@ TECH_SUBCLASSES = [
     "NoMaxDPI",
     "SmallMargins",
     "Trim",
+    "4800x1200dpi",
+    "Advanced",
 ]
 
 TECH_SUBCLASSES.sort()
@@ -295,7 +301,6 @@ class ModelData:
             'scan-style' : TYPE_INT,
             'scan-type' : TYPE_INT,
             'scan-src' : TYPE_INT,
-            'scan-color' : TYPE_INT,
             #'scan-duplex' : TYPE_BOOL,
             'status-battery-check' : TYPE_INT,
             'status-dynamic-counters' : TYPE_INT,
