@@ -202,12 +202,18 @@ def getPPDPath(addtional_paths=None):
 
 def getAllowableMIMETypes():
     """
-        Scan all /etc/cups/*.convs files for allowable file formats.
+        Scan all /etc/cups/*.convs and /usr/share/cups/mime 
+        files for allowable file formats.
     """
-    files = glob.glob("/etc/cups/*.convs")
-
+    paths = []
     allowable_mime_types = []
-
+    files = []
+    if os.path.exists("/etc/cups"):
+        paths.append("/etc/cups/*.convs")
+    if os.path.exists("/usr/share/cups/mime"):
+        paths.append("/usr/share/cups/mime/*.convs")
+    for path in paths:
+        files.extend(glob.glob(path))
     for f in files:
         #log.debug( "Capturing allowable MIME types from: %s" % f )
         conv_file = file(f, 'r')
@@ -481,7 +487,7 @@ def getPPDFile2(stripped_model, ppds): # New PPD find
     num_matches = len(matches)
 
     if num_matches == 0:
-        log.error("No PPD found for model %s using new algorithm. Trying old algorithm..." % stripped_model)
+        log.warn("No PPD found for model %s using new algorithm. Trying old algorithm..." % stripped_model)
         matches2 = getPPDFile(stripModel(stripped_model), ppds).items()
         log.debug(matches2)
         num_matches2 = len(matches2)
@@ -495,7 +501,7 @@ def getPPDFile2(stripped_model, ppds): # New PPD find
                     except AttributeError:
                         pdls = []
 
-                    if (prop.hpcups_build and 'hpijs' not in f) and \
+                    if (prop.hpcups_build and 'hpijs' not in f) or \
                        ((prop.hpijs_build and 'hpijs' in pdls) or (prop.hpcups_build and 'hpijs' not in pdls)):
                         matches.append((f, [p for p in pdls if p and p != 'hpijs']))
 
