@@ -1221,10 +1221,20 @@ PyObject * openPPD( PyObject * self, PyObject * args )
         return Py_BuildValue( "" ); // None
     }
 
-    g_ppd_file = cupsGetPPD( ( const char * ) printer );
+    if ( ( g_ppd_file = cupsGetPPD( ( const char * ) printer ) ) == NULL )
+    {
+        goto bailout;
+    }
+
+    if ( ( file = fopen( g_ppd_file, "r" )) == NULL )
+    {
+      unlink(g_ppd_file);
+      g_ppd_file = NULL;
+      goto bailout;
+    }
 
-    file = fopen( g_ppd_file, "r" );
     ppd = ppdOpen( file );
+    ppdLocalize( ppd );
     fclose( file );
 
     g_num_dests = cupsGetDests( &g_dests );
